(function () {


    function colorPicker(callback) {

        // Now create an image element
        var image = new Image();
        image.src = 'palette.png';

        // Create a div element
        // Create a canva element in the div
        var divElement = document.createElement('div'),
            canvasElement = document.createElement('canvas'),
            canvasImage;

        // Get the mouse position
        var event = window.event,
            mouseX = event.pageX,
            mouseY = event.pageY;

        function rgbToHex(R, G, B) {
            return toHex(R) + toHex(G) + toHex(B)
        }
        function toHex(n) {
            n = parseInt(n, 10);
            if (isNaN(n)) return "00";
            n = Math.max(0, Math.min(n, 255));
            return "0123456789ABCDEF".charAt((n - n % 16) / 16) + "0123456789ABCDEF".charAt(n % 16);
        }


        function show() {

            divElement.style.width = image.width + 'px';
            divElement.style.height = image.height + 'px';
            divElement.className += 'colorpicker';

            divElement.style.position = 'absolute';
            divElement.style.top = mouseY + 'px';
            divElement.style.left = mouseX + 'px';
            divElement.style.backgroundColor = "#FF0";

            canvasElement.width = image.width;
            canvasElement.height = image.height;
            canvasImage = canvasElement.getContext('2d');
            canvasImage.drawImage(image, 0, 0);

            divElement.appendChild(canvasElement);
            // Display element !
            document.querySelector('body').appendChild(divElement);
        }

        function remove(){
            divElement.remove();
            // remove listener on window click
            window.removeEventListener('click', remove);
        }

        // Just after the browser has finished to load the image we can add it in the canvas
        image.addEventListener('load', function () {
            show();
            // Handle the click on the palette
            canvasElement.addEventListener('click', function (event) {
                // Get the position of the mouse in the Canvas
                var x = event.pageX - this.offsetLeft;
                var y = event.pageY - this.offsetTop;

                // Get the Image Data
                var imageData = canvasImage.getImageData(x, y, 1, 1).data;

                // Convert into readable variable
                var Red = imageData[0];
                var Green = imageData[1];
                var Blue = imageData[2];

                // Create HEXA Value
                var color = rgbToHex(Red, Green, Blue);

                // Call the CallBack function with the color
                callback('#'+color);
                remove();
            });

            // It's a kind of cancellation a click
            window.addEventListener('click', remove);
        });
    }

    document.querySelector('#un').addEventListener('click', function () {
        colorPicker(function(color){
            console.log(color);
        });
    });

    document.querySelector('#deux').addEventListener('click', function () {
        colorPicker(function(color){
            console.log(color);
        });
    });

    document.querySelector('#trois').addEventListener('focus', function (e) {
        var target  = e.target;
        colorPicker(function(color){
            target.value = color;
        });
    });

})();
